"""Convert a Jupyter notebook to OK format for release."""

import argparse
import json
import pathlib
from otter.grade import grade_notebook
from glob import glob
import sys
import os

try:
    from .to_ok import gen_views
except ImportError:
    from to_ok import gen_views

def blockPrint():
	"""
	Disables printing to stdout.
	"""
	sys.stdout = open(os.devnull, 'w')

def enablePrint():
	"""
	Enables printing to stdout.
	"""
	sys.stdout = sys.__stdout__

def parse_args(args=None):
    parser = argparse.ArgumentParser()
    parser.add_argument("master", help="Notebook with solutions and tests.")
    parser.add_argument("result", help="Directory containing the result.")
    # parser.add_argument("endpoint", help="OK endpoint; e.g., cal/data8/sp19")
    parser.add_argument("--no-export-cell", help="Don't inject an export cell into the notebook",
                        default=False, action="store_true")
    parser.add_argument("--no-run-tests", help="Don't run tests.",
                        default=False, action="store_true")
    parser.add_argument("--no-init-cell", help="Don't automatically generate an Otter init cell",
                        default=False, action="store_true")
    parser.add_argument("--no-filter", help="Don't filter the PDF.",
                        default=False, action="store_true")
    parser.add_argument("--instructions", help="Additional submission instructions for students")
    parser.add_argument("files", nargs='*', help="Other support files needed for distribution (e.g. .py files, data files)")
    if args is None:
        return parser.parse_args()
    else:
        return parser.parse_args(args)


def run_tests(nb_path):
    """Run tests in the autograder version of the notebook."""
    results = grade_notebook(nb_path, glob(str(nb_path.parent / "tests" / "*.py")))
    assert results["total"] == results["possible"], "Some autograder tests failed"


def main(args=None):
    args = parse_args(args=args)
    master, result = pathlib.Path(args.master), pathlib.Path(args.result)
    print("Generating views...")
    gen_views(master, result, args)
    if not args.no_run_tests:
        print("Running tests...")
        blockPrint()
        run_tests(result / 'autograder'  / master.name )
        enablePrint()
        print("All tests passed!")

if __name__ == "__main__":
    main()



import unittest
import subprocess
from subprocess import PIPE
from oassign.oassign import main
import os

class TestConversion(unittest.TestCase):
    
    def test_convert_example(self):
        run_oassign_args = ["--no-run-tests", "test/example.ipynb", "test/output", "test/data.csv"]
        main(run_oassign_args)

        self.assertTrue(os.path.isdir("test/output"))
        self.assertEqual(os.listdir("test/output"), ["autograder", "student"])

        # check contents of autograder directory
        self.assertEqual(len(os.listdir("test/output/autograder")), 3)
        for f in ["tests", "data.csv", "example.ipynb"]:
            self.assertIn(f, os.listdir("test/output/autograder"))
        for f in ["q1H.py", "q1.py", "q3.py"]:
            self.assertIn(f, os.listdir("test/output/autograder/tests"))

        for file in ["example.ipynb", "data.csv", "tests/q1.py", "tests/q1H.py", "tests/q3.py"]:
            with open(os.path.join("test/output-correct/autograder", file)) as f:
                correct_contents = f.read()
            with open(os.path.join("test/output/autograder", file)) as f:
                contents = f.read()
            self.assertEqual(correct_contents, contents, "Autograder file {} incorrect".format(file))
        
        # check contents of student directory
        self.assertEqual(len(os.listdir("test/output/student")), 3)
        for f in ["tests", "data.csv", "example.ipynb"]:
            self.assertIn(f, os.listdir("test/output/student"))
        for f in ["q1.py", "q3.py"]:
            self.assertIn(f, os.listdir("test/output/student/tests"))

        for file in ["example.ipynb", "data.csv", "tests/q1.py", "tests/q3.py"]:
            with open(os.path.join("test/output-correct/student", file)) as f:
                correct_contents = f.read()
            with open(os.path.join("test/output/student", file)) as f:
                contents = f.read()
            self.assertEqual(correct_contents, contents, "Student file {} incorrect".format(file))
        


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

# okpy = [] # By default, do not require okpy so Gofer-Grader can be used instead.
# try:
#     import client
# except ImportError:
#     okpy = ['okpy']

setuptools.setup(
    name="otter-assign",
    version="0.0.1",
    author="Chris Pyles",
    author_email="cpyles@berkeley.edu",
    description="Jupyter notebook assignment formatting and distribution for Otter-Grader",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ucbds-infra/otter-assign",
    packages=setuptools.find_packages(),
    # package_data={'jassign': ['*.tplx']},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points = {
        'console_scripts': [
            'oassign = oassign.oassign:main',
            # 'jassign-pdf = jassign.jassign_pdf:main'
        ]
    },
    install_requires = [
        "pyyaml", "nbformat", "ipython", "nbconvert", "tqdm", "setuptools", "otter-grader", "pandas"
    ],
)
